@@ -279,7 +279,7 @@ async def rabbit_c2_rpc_callback(
             )
         except Exception as e:
             print(
-                "[-] Exception trying to send message back to container for rpc! " + str(e)
+                "Exception trying to send message back to container for rpc! " + str(e)
             )
             sys.stdout.flush()
 
@@ -308,12 +308,12 @@ async def connect_and_consume_rpc(main_config: dict):
                 print("Exception in connect_and_consume_rpc .consume: {}".format(str(e)))
                 sys.stdout.flush()
         except (ConnectionError, ConnectionRefusedError) as c:
-            print("[-} Connection to rabbitmq failed, trying again...")
+            print("Connection to rabbitmq failed, trying again...")
             sys.stdout.flush()
         except Exception as e:
-            print("[-] Exception in connect_and_consume_rpc connect: {}\n trying again...".format(str(e)))
+            print("Exception in connect_and_consume_rpc connect: {}\n trying again...".format(str(e)))
             sys.stdout.flush()
-        await asyncio.sleep(2)
+        await asyncio.sleep(5)
 
 
 async def mythic_service():
@@ -351,18 +351,21 @@ async def mythic_service():
                 )
                 # just want to handle one message at a time so we can clean up and be ready
                 await channel.set_qos(prefetch_count=30)
-                print("[+] Listening for c2.modify.{}.#".format(hostname))
-                sys.stdout.flush()
                 task = queue.consume(callback)
                 await sync_classes()
+                print("Listening for c2.modify.{}.#".format(hostname))
                 task4 = asyncio.ensure_future(connect_and_consume_rpc(main_config))
-                result = await asyncio.gather(task, task4)
-                # send_status(message="", routing_key="c2.status.{}.stopped.stop".format(hostname))
+                result = await asyncio.wait_for(task, task4)
             except Exception as e:
-                print("[-] Exception in mythic_service: " + str(traceback.format_exc()))
+                print("Exception in mythic_service: " + str(traceback.format_exc()))
                 sys.stdout.flush()
+        except (ConnectionError, ConnectionRefusedError) as c:
+            print("Connection to rabbitmq failed, trying again...")
+            sys.stdout.flush()
         except Exception as e:
-            await asyncio.sleep(2)
+            print("Exception in mythic_service: " + str(traceback.format_exc()))
+            sys.stdout.flush()
+        await asyncio.sleep(5)
     
 
 
@@ -387,9 +390,15 @@ async def heartbeat_loop():
             exchange = await channel.declare_exchange(
                 "mythic_traffic", aio_pika.ExchangeType.TOPIC
             )
+        except (ConnectionError, ConnectionRefusedError) as c:
+            print("Connection to rabbitmq failed, trying again...")
+            sys.stdout.flush()
+            await asyncio.sleep(5)
+            continue
         except Exception as e:
-            print(str(e))
-            await asyncio.sleep(2)
+            print("Exception in heartbeat_loop: " + str(traceback.format_exc()))
+            sys.stdout.flush()
+            await asyncio.sleep(5)
             continue
         while True:
             try:
